@@ -10,6 +10,7 @@ from qualys_etl.etld_lib import etld_lib_datetime
 from qualys_etl.etld_lib import etld_lib_sqlite_tables
 
 global setup_completed_flag           # Set to true when completed
+global system_usage_counters          # Dict of system usage counters
 # APPLICATION
 global qetl_code_dir                  # Parent Directory of qualys_etl
 global qetl_code_dir_child            # qualys_etl directory
@@ -216,6 +217,7 @@ global was_test_number_of_files_to_extract
 
 qetl_create_user_dirs_ok_flag = False      # Automatically create unknown user directories default - False
 qetl_manage_user_selected_datetime = None  # Initialize qetl_manage_user datetime to None
+system_usage_counters = []                 # Initialize system usage counters dictionary
 
 
 def prepare_extract_batch_file_name(next_batch_number_str='batch_000001',
@@ -1469,10 +1471,19 @@ def set_limit_open_files_to_hard_limit_for_multiprocessing_pipes(module_function
     logger_method(f"limit_open_files after:  {module_function} limit_soft={limit_soft}, limit_hard={limit_hard}")
 
 
-def log_ram_disk_stats():
-    etld_lib_functions.log_system_information(
+def total_system_stats_cpu_ram_swap_disk(sys_stat: dict):
+    global system_usage_counters
+    system_usage_counters.append(sys_stat)
+
+
+def log_system_stats_cpu_ram_swap_disk():
+    global system_usage_counters
+    system_stat = etld_lib_functions.log_system_information(
         data_directory=qetl_user_home_dir,
         logger_method=etld_lib_functions.logger.info)
+
+    system_usage_counters.append(system_stat)
+
     etld_lib_functions.if_disk_space_usage_greater_than_90_log_warning(
         data_directory=qetl_user_home_dir,
         logger_method=etld_lib_functions.logger.warn)
@@ -1514,7 +1525,7 @@ def main():
     setup_test_system_vars()
 
     set_limit_open_files_to_hard_limit_for_multiprocessing_pipes(logger_method=etld_lib_functions.logger.info)
-    log_ram_disk_stats()
+    log_system_stats_cpu_ram_swap_disk()
     setup_completed()
 
 
