@@ -11,6 +11,7 @@ from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_sqlite_tables
 from qualys_etl.etld_lib import etld_lib_test_system
+from qualys_etl.etld_lib import etld_lib_credentials
 global http_error_codes_v2_api
 
 
@@ -275,6 +276,7 @@ def extract_qualys(
 
     # TODO For 401 Unauthorized with expired token, retry.  This is an extreme edge case.
     time_sleep = 0
+    debug_error_code = True
     for _ in range(try_extract_max_count):
         try:
             headers['User-Agent'] = f"qualysetl_v{qualys_etl.__version__}"
@@ -285,6 +287,15 @@ def extract_qualys(
                     qualys_headers_multiprocessing_dict['batch_000001'] = get_qualys_headers(r)
                 else:
                     qualys_headers_multiprocessing_dict[multi_proc_batch_number] = get_qualys_headers(r)
+                    etld_lib_functions.logger.info(f"Testing: {multi_proc_batch_number}")
+
+                    # if debug_error_code is True and multi_proc_batch_number == 'batch_000003':
+                    #     debug_error_code = False
+                    #     r.status_code = 401
+                    #
+                    # if debug_error_code is True and multi_proc_batch_number == 'batch_000005':
+                    #     debug_error_code = False
+                    #     r.status_code = 401
 
                 etld_lib_functions.logger.info(f"Qualys Headers: {qualys_headers}")
                 if r.status_code == 200:
@@ -308,11 +319,21 @@ def extract_qualys(
                     message = get_http_error_code_message_v2_api(str(r.status_code))
                     etld_lib_functions.logger.warning(f"HTTP USER: {cred_dict['username']} url: {url}")
                     raise Exception(f"HTTP Status is: {r.status_code}, message: {message}")
+                elif r.status_code == 401:
+                    if "/rest/2.0/search/am/asset" in url:
+                        message = get_http_error_code_message_v2_api(str(r.status_code))
+                        etld_lib_functions.logger.warning(f"HTTP USER: {cred_dict['username']} url: {url}")
+                        etld_lib_functions.logger.warning(f"HTTP {r.status_code}: warning. message={message}")
+                        etld_lib_functions.logger.warning(f"HTTP {r.status_code}: "
+                                                          f"retrying cred gateway for:{url}")
+                        cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=True, cred=cred_dict)
+                        raise Exception(f"HTTP Status is: {r.status_code}, message: {message}")
                 else:
                     message = get_http_error_code_message_v2_api(str(r.status_code))
                     etld_lib_functions.logger.error(f"HTTP USER: {cred_dict['username']} url: {url}")
                     etld_lib_functions.logger.error(f"HTTP {r.status_code}, exiting. message={message}")
                     exit(1)
+
         except Exception as e:
             time_sleep = time_sleep + 30
             if time_sleep > 90:
@@ -330,3 +351,5 @@ def extract_qualys(
         etld_lib_functions.logger.error(f"extract file: {Path(output_file).name}")
         exit(1)
 
+    return cred_dict  # For HTTP 401 Gateway Edge Case
+
