@@ -336,54 +336,83 @@ class DisplayCounterToLog:
 
 
 def log_system_information(logger_method=print, data_directory="/opt/qetl/users"):
+    # TODO Calculate final averages of cpu, mem usage.
+    sys_stat_counters = {
+        'cpu_usage_pct': get_cpu_usage_pct(),
+        'cpu_frequency': get_cpu_frequency(),
+        'cpu_count': get_cpu_count(),
+        'ram_usage_pct': get_ram_usage_pct(),
+        'ram_size_total_in_mb': get_ram_size_total_in_mb(),
+        'ram_size_usage_in_mb': get_ram_size_usage_in_mb(),
+        'ram_size_available_in_mb': get_ram_size_available_in_mb(),
+        'swap_usage_pct': get_swap_usage_pct(),
+        'swap_size_total_in_mb': get_swap_size_total_in_mb(),
+        'swap_size_usage_in_mb': get_swap_size_usage_in_mb(),
+        'swap_size_available_in_mb': get_swap_size_available_in_mb(),
+        'disk_usage_pct': 0,
+        'disk_size_total_in_mb': 0,
+        'disk_size_usage_in_mb': 0,
+        'disk_size_available_in_mb': 0,
+    }
+
     logger_method(
-        f'SYS STAT: CPU usage={psutil.cpu_percent(interval=0.5)} %, '
+        f'SYS STAT: CPU usage={sys_stat_counters["cpu_usage_pct"]} %, '
         f'frequency='
-        f'{get_cpu_frequency()} MHz, '
+        f'{sys_stat_counters["cpu_frequency"]} MHz, '
         f'count='
-        f'{get_cpu_count()}'
+        f'{sys_stat_counters["cpu_count"]}'
     )
     logger_method(
         f'SYS STAT: RAM usage='
-        f'{get_ram_usage_pct()} %, '
+        f'{sys_stat_counters["ram_usage_pct"]} %, '
         f'total='
-        f'{get_ram_size_total_in_mb():,.0f} MB, '
+        f'{sys_stat_counters["ram_size_total_in_mb"]:,.0f} MB, '
         f'used='
-        f'{get_ram_size_usage_in_mb():,.0f} MB, '
+        f'{sys_stat_counters["ram_size_usage_in_mb"]:,.0f} MB, '
         f'available='
-        f'{get_ram_size_available_in_mb():,.0f} MB '
+        f'{sys_stat_counters["ram_size_available_in_mb"]:,.0f} MB '
     )
     logger_method(
         f'SYS STAT: SWAP usage='
-        f'{get_swap_usage_pct()} %, '
+        f'{sys_stat_counters["swap_usage_pct"]} %, '
         f'total='
-        f'{get_swap_total_in_mb():,.0f} MB, '
+        f'{sys_stat_counters["swap_size_total_in_mb"]:,.0f} MB, '
         f'used='
-        f'{get_swap_usage_in_mb():,.0f} MB, '
+        f'{sys_stat_counters["swap_size_usage_in_mb"]:,.0f} MB, '
         f'available='
-        f'{get_swap_available_in_mb():,.0f} MB '
+        f'{sys_stat_counters["swap_size_available_in_mb"]:,.0f} MB '
     )
 
     try:
+        disk_usage_pct = get_disk_usage_pct(data_dir=data_directory)
+        disk_size_total_in_mb = get_disk_size_total_in_mb(data_dir=data_directory)
+        disk_size_usage_in_mb = get_disk_size_usage_in_mb(data_dir=data_directory)
+        disk_size_available_in_mb = get_disk_size_available_in_mb(data_dir=data_directory)
+        sys_stat_counters['disk_usage_pct'] = disk_usage_pct
+        sys_stat_counters['disk_size_total_in_mb'] = disk_size_total_in_mb
+        sys_stat_counters['disk_size_usage_in_mb'] = disk_size_usage_in_mb
+        sys_stat_counters['disk_size_available_in_mb'] = disk_size_available_in_mb
         logger_method(
             f'SYS STAT: DISK usage='
-            f'{get_disk_size_pct(data_dir=data_directory)} %, '
+            f'{sys_stat_counters["disk_usage_pct"]} %, '
             f'total='
-            f'{get_disk_size_total(data_dir=data_directory):,.0f} MB, '
+            f'{sys_stat_counters["disk_size_total_in_mb"]:,.0f} MB, '
             f'used='
-            f'{get_disk_size_usage(data_dir=data_directory):,.0f} MB, '
+            f'{sys_stat_counters["disk_size_usage_in_mb"]:,.0f} MB, '
             f'available='
-            f'{get_disk_size_remaining(data_dir=data_directory):,.0f} MB, '
+            f'{sys_stat_counters["disk_size_available_in_mb"]:,.0f} MB, '
             f'path='
             f'{data_directory}, '
         )
     except Exception as e:
         pass
 
+    return sys_stat_counters
+
 
 def if_disk_space_usage_greater_than_90_log_warning(logger_method=print, data_directory="/opt/qetl/users"):
     try:
-        disk_size_usage_pct = int(get_disk_size_pct(data_dir=data_directory))
+        disk_size_usage_pct = int(get_disk_usage_pct(data_dir=data_directory))
         if disk_size_usage_pct > 90:
             logger_method(f'SYS WARNING: DISK percent usage > 90% at {disk_size_usage_pct}%')
     except Exception as e:
@@ -391,16 +420,16 @@ def if_disk_space_usage_greater_than_90_log_warning(logger_method=print, data_di
 
 
 def if_swap_space_total_is_zero_abort(logger_method=print):
-    if int(get_swap_total_in_mb()) > 0:
+    if int(get_swap_size_total_in_mb()) > 0:
         pass
     else:
         logger_method(f'SYS ERROR: Please contact your systems administrator to configure swap space.')
-        logger_method(f'SYS ERROR: current swap space size is: {get_swap_total_in_mb():,.0f} MB, ')
+        logger_method(f'SYS ERROR: current swap space size is: {get_swap_size_total_in_mb():,.0f} MB, ')
         exit(1)
 
 
 def if_swap_space_total_is_low_log_warning(logger_method=print):
-    if int(get_swap_total_in_mb()) < 4000:
+    if int(get_swap_size_total_in_mb()) < 4000:
         logger_method(f'SYS WARNING: SWAP size total is < 4 Gig. '
                       f'Consider increasing SWAP to support larger batch jobs and sql queries')
 
@@ -421,23 +450,23 @@ def proc_table(logger_method=print):
             logger_method(f'PID STAT: PID CHILDREN={proc.pid}, CHILDREN={p.children(recursive=True)}')
 
 
-def get_disk_size_pct(data_dir="/opt/qetl/users"):
+def get_disk_usage_pct(data_dir="/opt/qetl/users"):
     return psutil.disk_usage(data_dir).percent
 
 
-def get_disk_size_total(data_dir="/opt/qetl/users"):
-    return psutil.disk_usage(data_dir).total / 1024 / 1024
+def get_disk_size_total_in_mb(data_dir="/opt/qetl/users"):
+    return int(psutil.disk_usage(data_dir).total / 1024 / 1024)
 
 
-def get_disk_size_usage(data_dir="/opt/qetl/users"):
-    return psutil.disk_usage(data_dir).used / 1024 / 1024
+def get_disk_size_usage_in_mb(data_dir="/opt/qetl/users"):
+    return int(psutil.disk_usage(data_dir).used / 1024 / 1024)
 
 
-def get_disk_size_remaining(data_dir="/opt/qetl/users"):
+def get_disk_size_available_in_mb(data_dir="/opt/qetl/users"):
     total_disk_space = psutil.disk_usage(data_dir).total / 1024 / 1024
     used_disk_space = psutil.disk_usage(data_dir).used / 1024 / 1024
     available_disk_space = total_disk_space - used_disk_space
-    return available_disk_space
+    return int(available_disk_space)
 
 
 def get_cpu_usage_pct():
@@ -468,19 +497,19 @@ def get_ram_size_available_in_mb():
     return int(psutil.virtual_memory().available) / 1024 / 1034
 
 
-def get_swap_usage_in_mb():
+def get_swap_size_usage_in_mb():
     return int(psutil.swap_memory().used) / 1024 / 1024
 
 
-def get_swap_total_in_mb():
+def get_swap_size_total_in_mb():
     return int(psutil.swap_memory().total) / 1024 / 1024
 
 
-def get_swap_available_in_mb():
+def get_swap_size_available_in_mb():
     total_swap_space = psutil.swap_memory().total / 1024 / 1024
     used_swap_space = psutil.swap_memory().used / 1024 / 1024
     available_swap_space = total_swap_space - used_swap_space
-    return available_swap_space
+    return int(available_swap_space)
 
 
 def get_swap_usage_pct():
