@@ -160,7 +160,7 @@ def spawned_process_status_update():
         etld_lib_functions.logger.info(
             f"Job PID {str(spawned_process.pid)} {target_module_to_run.__name__} "
             f"job running in background.")
-        etld_lib_config.log_ram_disk_stats()
+        etld_lib_config.log_system_stats_cpu_ram_swap_disk()
         spawned_process_status_count = 1
         if etl_files_are_stalled():
             terminate_spawned_process_due_to_stalled_output()
