@@ -382,20 +382,20 @@ def if_user_selected_test_qualys_basic_authentication_login(first_time=False):
         return False
 
 
-def if_user_selected_test_qualys_gateway_token_login(first_time=False):
-    if command_line_arguments.test is not None or first_time is not False:
-        etld_lib_functions.main(log_level=logging.INFO, my_logger_prog_name='qetl_manage_user')
-        etld_lib_config.main()
-        etld_lib_credentials.main()
-        credentials = etld_lib_credentials.get_cred()
-        print(f"Qualys Login Test for {credentials.get('username')} "
-              f"at gateway_fqdn_server: {credentials.get('gateway_fqdn_server')}\n")
-        etld_lib_credentials.test_gateway_auth()
-        if etld_lib_credentials.login_failed is not True:
-            print(f"Testing Qualys Login for {credentials.get('username')} "
-                  f"Succeeded at {credentials.get('api_fqdn_server')}\n"
-                  f"    with HTTPS Return Code: {etld_lib_credentials.http_return_code}.")
-        etld_lib_functions.main(log_level=logging.WARN, my_logger_prog_name='qetl_manage_user')
+# def if_user_selected_test_qualys_gateway_token_login(first_time=False):
+#     if command_line_arguments.test is not None or first_time is not False:
+#         etld_lib_functions.main(log_level=logging.INFO, my_logger_prog_name='qetl_manage_user')
+#         etld_lib_config.main()
+#         etld_lib_credentials.main()
+#         credentials = etld_lib_credentials.get_cred()
+#         print(f"Qualys Login Test for {credentials.get('username')} "
+#               f"at gateway_fqdn_server: {credentials.get('gateway_fqdn_server')}\n")
+#         etld_lib_credentials.test_gateway_auth()
+#         if etld_lib_credentials.login_failed is not True:
+#             print(f"Testing Qualys Login for {credentials.get('username')} "
+#                   f"Succeeded at {credentials.get('api_fqdn_server')}\n"
+#                   f"    with HTTPS Return Code: {etld_lib_credentials.http_return_code}.")
+#         etld_lib_functions.main(log_level=logging.WARN, my_logger_prog_name='qetl_manage_user')
 
 
 def if_user_selected_print_directory_listing_report():
@@ -553,7 +553,16 @@ def setup_qualys_etl_user_home_environment_in_memory_and_in_etld_lib_config():
             exit(1)
 
 
+def if_root_user_abort_program(logger_method=print):
+    userid = int(os.getuid())
+    if userid == 0:
+        logger_method(f"Sorry, please run as non-root user.  Current userid is: {userid}")
+        logger_method(f"Exiting program - Cannot run qetl_manage_user as root user.")
+        exit(1)
+
+
 def main():
+    if_root_user_abort_program()
     get_command_line_arguments(sys.argv[1:])
     test_command_line_arguments()
     setup_qualys_etl_user_home_environment_in_memory_and_in_etld_lib_config()
